EncoderOperand

Enum EncoderOperand 

pub enum EncoderOperand {
    None,
    Reg(Register),
    Mem(MemoryOperand),
    Imm(u64),
    Rel(i32),
}
Operand for encoding

Represents the different types of operands that can be used when encoding instructions.

Variants



None

No operand (placeholder)



Reg(Register)

Register operand



Mem(MemoryOperand)

Memory operand



Imm(u64)

Unsigned immediate value



Rel(i32)

Signed relative offset (for branches)

Implementations

Source

impl EncoderOperand

pub const fn reg(register: Register) -> Self

Create a register operand

pub const fn mem(memory: MemoryOperand) -> Self

Create a memory operand

pub const fn imm(value: u64) -> Self

Create an immediate operand

pub const fn rel(offset: i32) -> Self

Create a relative offset operand

pub const fn is_register(&self) -> bool

Check if this is a register operand

pub const fn is_memory(&self) -> bool

Check if this is a memory operand

pub const fn is_immediate(&self) -> bool

Check if this is an immediate operand

pub const fn is_relative(&self) -> bool

Check if this is a relative offset operand

pub const fn as_register(&self) -> Option<Register>

Get the register if this is a register operand

pub const fn as_memory(&self) -> Option<&MemoryOperand>

Get the memory operand if this is a memory operand

pub const fn as_immediate(&self) -> Option<u64>

Get the immediate value if this is an immediate operand

pub const fn as_relative(&self) -> Option<i32>

Get the relative offset if this is a relative operand